EXPORTS
	??0CPeninputLayoutWindowJp@@IAE@PAVCFepUiLayout@@PAVMPeninputLayoutContext@@@Z @ 1 NONAME ; CPeninputLayoutWindowJp::CPeninputLayoutWindowJp(class CFepUiLayout *, class MPeninputLayoutContext *)
	??1CFepInputContextFieldJp@@UAE@XZ @ 2 NONAME ; CFepInputContextFieldJp::~CFepInputContextFieldJp(void)
	??1CPeninputHiraganaKanji@@UAE@XZ @ 3 NONAME ; CPeninputHiraganaKanji::~CPeninputHiraganaKanji(void)
	??1CPeninputLayoutWindowJp@@UAE@XZ @ 4 NONAME ; CPeninputLayoutWindowJp::~CPeninputLayoutWindowJp(void)
	?CancelInlineL@CFepInputContextFieldJp@@QAEXXZ @ 5 NONAME ; void CFepInputContextFieldJp::CancelInlineL(void)
	?CancelRepeat@CPeninputHiraganaKanji@@QAEXXZ @ 6 NONAME ; void CPeninputHiraganaKanji::CancelRepeat(void)
	?CandidateWindow@CPeninputLayoutWindowJp@@QAEPAVCPeninputJapaneseCandidateWnd@@XZ @ 7 NONAME ; class CPeninputJapaneseCandidateWnd * CPeninputLayoutWindowJp::CandidateWindow(void)
	?CharacterAroundCursor@CFepInputContextFieldJp@@QAE?AVTChar@@H@Z @ 8 NONAME ; class TChar CFepInputContextFieldJp::CharacterAroundCursor(int)
	?CharacterOnCursor@CFepInputContextFieldJp@@QAE?AVTChar@@XZ @ 9 NONAME ; class TChar CFepInputContextFieldJp::CharacterOnCursor(void)
	?CharacterRangeWindow@CPeninputLayoutWindowJp@@QAEPAVCPeninputJapaneseCandidateWnd@@XZ @ 10 NONAME ; class CPeninputJapaneseCandidateWnd * CPeninputLayoutWindowJp::CharacterRangeWindow(void)
	?Closed@CPeninputLayoutWindowJp@@QAEXXZ @ 11 NONAME ; void CPeninputLayoutWindowJp::Closed(void)
	?CommitInlineL@CFepInputContextFieldJp@@QAEXXZ @ 12 NONAME ; void CFepInputContextFieldJp::CommitInlineL(void)
	?ConstructFromResourceL@CPeninputLayoutWindowJp@@UAEXXZ @ 13 NONAME ; void CPeninputLayoutWindowJp::ConstructFromResourceL(void)
	?ConstructL@CPeninputJapaneseView@@QAEXXZ @ 14 NONAME ; void CPeninputJapaneseView::ConstructL(void)
	?CreateAllControlsL@CPeninputLayoutWindowJp@@UAEXXZ @ 15 NONAME ; void CPeninputLayoutWindowJp::CreateAllControlsL(void)
	?CurrentItemIndex@CPeninputJapaneseCandidateWnd@@QBEHXZ @ 16 NONAME ; int CPeninputJapaneseCandidateWnd::CurrentItemIndex(void) const
	?CursorPosition@CFepInputContextFieldJp@@QBEHXZ @ 17 NONAME ; int CFepInputContextFieldJp::CursorPosition(void) const
	?DivisionPoint@CFepInputContextFieldJp@@QBEHXZ @ 18 NONAME ; int CFepInputContextFieldJp::DivisionPoint(void) const
	?HandleControlEvent@CPeninputLayoutWindowJp@@UAEXHPAVCFepUiBaseCtrl@@ABVTDesC16@@@Z @ 19 NONAME ; void CPeninputLayoutWindowJp::HandleControlEvent(int, class CFepUiBaseCtrl *, class TDesC16 const &)
	?HandleControlEventJpL@CPeninputHiraganaKanji@@QAEXHABVTDesC16@@@Z @ 20 NONAME ; void CPeninputHiraganaKanji::HandleControlEventJpL(int, class TDesC16 const &)
	?HandleKeyEvent@CPeninputHiraganaKanji@@QAEHABVTRawEvent@@@Z @ 21 NONAME ; int CPeninputHiraganaKanji::HandleKeyEvent(class TRawEvent const &)
	?HandlePendingEventL@CPeninputHiraganaKanji@@QAEHXZ @ 22 NONAME ; int CPeninputHiraganaKanji::HandlePendingEventL(void)
	?HandlePointerDownEventL@CPeninputLayoutWindowJp@@UAEPAVCFepUiBaseCtrl@@ABVTPoint@@@Z @ 23 NONAME ; class CFepUiBaseCtrl * CPeninputLayoutWindowJp::HandlePointerDownEventL(class TPoint const &)
	?HandlePointerMoveEventL@CPeninputLayoutWindowJp@@UAEPAVCFepUiBaseCtrl@@ABVTPoint@@@Z @ 24 NONAME ; class CFepUiBaseCtrl * CPeninputLayoutWindowJp::HandlePointerMoveEventL(class TPoint const &)
	?HandlePointerUpEventL@CPeninputLayoutWindowJp@@UAEPAVCFepUiBaseCtrl@@ABVTPoint@@@Z @ 25 NONAME ; class CFepUiBaseCtrl * CPeninputLayoutWindowJp::HandlePointerUpEventL(class TPoint const &)
	?HidePopup@CPeninputJapaneseCandidateWnd@@QAEXXZ @ 26 NONAME ; void CPeninputJapaneseCandidateWnd::HidePopup(void)
	?InputContextField@CPeninputLayoutWindowJp@@QAEPAVCFepInputContextFieldJp@@XZ @ 27 NONAME ; class CFepInputContextFieldJp * CPeninputLayoutWindowJp::InputContextField(void)
	?NewL@CFepInputContextFieldJp@@SAPAV1@VTRect@@PAVCFepUiLayout@@H@Z @ 28 NONAME ; class CFepInputContextFieldJp * CFepInputContextFieldJp::NewL(class TRect, class CFepUiLayout *, int)
	?NewL@CPeninputHiraganaKanji@@SAPAV1@PAVCPtiEngine@@PAVCFepUiLayout@@PAVCFepInputContextFieldJp@@PAVCPeninputJapaneseCandidateWnd@@PAVCPeninputJapanesePredictiveWnd@@@Z @ 29 NONAME ; class CPeninputHiraganaKanji * CPeninputHiraganaKanji::NewL(class CPtiEngine *, class CFepUiLayout *, class CFepInputContextFieldJp *, class CPeninputJapaneseCandidateWnd *, class CPeninputJapanesePredictiveWnd *)
	?NewL@CPeninputJapaneseCandidateWnd@@SAPAV1@PAVCFepUiLayout@@HPBVCCoeControl@@@Z @ 30 NONAME ; class CPeninputJapaneseCandidateWnd * CPeninputJapaneseCandidateWnd::NewL(class CFepUiLayout *, int, class CCoeControl const *)
	?NewL@CPeninputJapanesePredictiveWnd@@SAPAV1@PAVCFepUiLayout@@HPBVCCoeControl@@@Z @ 31 NONAME ; class CPeninputJapanesePredictiveWnd * CPeninputJapanesePredictiveWnd::NewL(class CFepUiLayout *, int, class CCoeControl const *)
	?Opened@CPeninputLayoutWindowJp@@QAEXXZ @ 32 NONAME ; void CPeninputLayoutWindowJp::Opened(void)
	?PredictiveWindow@CPeninputLayoutWindowJp@@QAEPAVCPeninputJapanesePredictiveWnd@@XZ @ 33 NONAME ; class CPeninputJapanesePredictiveWnd * CPeninputLayoutWindowJp::PredictiveWindow(void)
	?RepeatClearKeyStart@CPeninputHiraganaKanji@@QAEXXZ @ 34 NONAME ; void CPeninputHiraganaKanji::RepeatClearKeyStart(void)
	?SetControlsFont@CPeninputLayoutWindowJp@@UAEXXZ @ 35 NONAME ; void CPeninputLayoutWindowJp::SetControlsFont(void)
	?SetCursorPosition@CFepInputContextFieldJp@@QAEXH@Z @ 36 NONAME ; void CFepInputContextFieldJp::SetCursorPosition(int)
	?SetEditorTextL@CPeninputHiraganaKanji@@QAEXABUTFepInputContextFieldData@@@Z @ 37 NONAME ; void CPeninputHiraganaKanji::SetEditorTextL(struct TFepInputContextFieldData const &)
	?SetPosition@CPeninputJapaneseCandidateWnd@@QAEXABVTPoint@@@Z @ 38 NONAME ; void CPeninputJapaneseCandidateWnd::SetPosition(class TPoint const &)
	?SetRect@CPeninputJapaneseCandidateWnd@@UAEXABVTRect@@@Z @ 39 NONAME ; void CPeninputJapaneseCandidateWnd::SetRect(class TRect const &)
	?SetRect@CPeninputJapanesePredictiveWnd@@UAEXABVTRect@@@Z @ 40 NONAME ; void CPeninputJapanesePredictiveWnd::SetRect(class TRect const &)
	?SetTextL@CFepInputContextFieldJp@@QAEXABUTFepInputContextFieldData@@@Z @ 41 NONAME ; void CFepInputContextFieldJp::SetTextL(struct TFepInputContextFieldData const &)
	?ShowPopupL@CPeninputJapaneseCandidateWnd@@QAEXPAVCDesC16ArrayFlat@@H@Z @ 42 NONAME ; void CPeninputJapaneseCandidateWnd::ShowPopupL(class CDesC16ArrayFlat *, int)
	?StartInlineL@CFepInputContextFieldJp@@QAEXXZ @ 43 NONAME ; void CFepInputContextFieldJp::StartInlineL(void)
	?UpdateInlineL@CFepInputContextFieldJp@@QAEXAAVTDesC16@@HW4TTransitoryInputAreaState@1@@Z @ 44 NONAME ; void CFepInputContextFieldJp::UpdateInlineL(class TDesC16 &, int, enum CFepInputContextFieldJp::TTransitoryInputAreaState)
	?CompleteInlineL@CFepInputContextFieldJp@@QAEXXZ @ 45 NONAME ; void CFepInputContextFieldJp::CompleteInlineL(void)
	?ICFDisableRegionUpdating@CPeninputLayoutWindowJp@@QAEXXZ @ 46 NONAME ; void CPeninputLayoutWindowJp::ICFDisableRegionUpdating(void)
	?ICFEnableRegionUpdating@CPeninputLayoutWindowJp@@QAEXXZ @ 47 NONAME ; void CPeninputLayoutWindowJp::ICFEnableRegionUpdating(void)

